@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: openvasd.c 2002 2008-12-15 20:30:29Z jan $
+* $Id: openvasd.c 2479 2009-02-13 10:29:28Z felix $
 * Description: Runs the OpenVAS-server.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -24,8 +24,22 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
-*
-*/ 
+*/
+
+/**
+ * @mainpage
+ *
+ * @section Introduction
+ * @verbinclude README
+ *
+ * @section license License Information
+ * @verbinclude COPYING
+ */
+
+/**
+ * @file
+ * OpenVAS Server main module, runs the server.
+ */
 
 #include <includes.h>
 #include <harglists.h>
@@ -68,7 +82,8 @@ int allow_severity = LOG_NOTICE;
 
 extern char * nasl_version();
 extern char * nessuslib_version();
-/*
+
+/**
  * Globals that should not be touched
  */
 int g_max_hosts = 15;
@@ -87,6 +102,11 @@ struct openvas_rules * g_rules;
 static char * orig_argv[64];
 static int restart = 0;
 
+/**
+ * SSL context may be kept once it is inited.
+ */
+static ovas_server_context_t ovas_server_ctx = NULL;
+
 
 /*
  * Functions prototypes
@@ -99,7 +119,8 @@ static void server_thread (struct arglist *);
 
 
 
-static struct in_addr * convert_ip_addresses(char * ips)
+static struct in_addr*
+convert_ip_addresses (char * ips)
 {
  char * t;
  struct in_addr addr;
@@ -151,24 +172,17 @@ static struct in_addr * convert_ip_addresses(char * ips)
    num_allocated ++;
    ret = erealloc(ret, (num_allocated + 1) * sizeof(struct in_addr));
   }
- 
- 
- 
+
  ret[num].s_addr = 0;
  ret = erealloc(ret, ( num + 1 ) * sizeof(struct in_addr));
  efree(&orig);
  return ret;
-} 
-  
-  
-  
-
+}
 
 
 
 static void
-dump_cfg_specs
-  (struct arglist *prefs)
+dump_cfg_specs (struct arglist *prefs)
 {
  while(prefs && prefs->next)
  {
@@ -193,8 +207,7 @@ arg_replace_value(arglist, name, type, length, value)
 
 
 static void
-start_daemon_mode
-  (void)
+start_daemon_mode (void)
 {
   char *s;
   int fd;
@@ -258,15 +271,14 @@ start_daemon_mode
 
 
 static void
-end_daemon_mode
-  (void)
+end_daemon_mode (void)
 {
-
   /* clean up all processes the process group */
   make_em_die (SIGTERM);
 }
 
-static void restart_openvasd()
+static void
+restart_openvasd ()
 {
  char * path;
  char fpath[1024];
@@ -307,14 +319,8 @@ sighup(i)
 }
 
 
-
-/*
- * SSL context may be kept once it is inited.
- */
-static ovas_server_context_t ovas_server_ctx = NULL;
-
 static void
-server_thread(struct arglist * globals)
+server_thread (struct arglist * globals)
 {
  struct sockaddr_in * address = arg_get_value(globals, "client_address");
  struct arglist * plugins = arg_get_value(globals, "plugins");
@@ -408,8 +414,6 @@ if(preferences_benice(prefs))nice(10);
    goto shutdown_and_exit;
  }
   else {
-     char * uhome ;
-     char * phome;
    efree(&asciiaddr);
    if(perms){
      	rules_add(&rules, &perms, NULL);
@@ -420,14 +424,6 @@ if(preferences_benice(prefs))nice(10);
 #endif	
 	arg_set_value(globals, "rules", -1, rules);
    }
-   
-   uhome = user_home(globals);
-   phome = emalloc(strlen(uhome) + strlen("plugins") + 2);
-   sprintf(phome, "%s/plugins", uhome);
-   store_init_user(phome);
-   efree(&uhome);
-   efree(&phome);
-   plugins = plugins_reload_user(globals, prefs, plugins);
 
    arg_set_value(globals, "plugins", -1, plugins);
 
@@ -478,8 +474,8 @@ wait :
 }
 
 
-static void 
-main_loop()
+static void
+main_loop ()
 {
   char		*cert, *key, *passwd, *ca_file, *s, *ssl_ver;
   int force_pubkey_auth;
@@ -680,18 +676,20 @@ main_loop()
 }
 
 
-/*
+/**
  * Initialization of the network : 
- * we setup the socket that will listen for
- * incoming connections on port <port> on address
- * <addr> (which are set to 1241 and INADDR_ANY by
- * default)
- */ 
+ * we setup the socket that will listen for incoming connections on port \<port\>
+ * on address \<addr\> (which are set to OPENVAS_IANA_OTP_PORT and INADDR_ANY by
+ * default).
+ * 
+ * @param port Port on which to listen.
+ * @param[out] sock Socket to be initialized.
+ * @param addr Adress.
+ * 
+ * @return 0 on success. Exit(1)s on failure.
+ */
 static int 
-init_network(port, sock, addr)
-     int port;
-     int * sock;
-     struct in_addr addr;
+init_network (int port, int* sock, struct in_addr addr)
 {
   int option = 1;
 
@@ -725,15 +723,14 @@ init_network(port, sock, addr)
   return(0);
 }
 
-/*
+/**
  * Initialize everything
+ * 
+ * @param stop_early 1: do some initialization, 2: no initialization.
  */
 static int 
-init_openvasd (options, first_pass, stop_early, be_quiet)
-     struct arglist * options;    
-     int first_pass;
-     int stop_early; /* 1: do some initialization, 2: no initialization */
-     int be_quiet;
+init_openvasd (struct arglist * options, int first_pass, int stop_early,
+               int be_quiet)
 {
   int  isck = -1;
   struct arglist * plugins = NULL;
@@ -770,11 +767,9 @@ init_openvasd (options, first_pass, stop_early, be_quiet)
 
 
   if ( stop_early == 0 ) {
-    char * dir;
+    if (store_init(arg_get_value(preferences, "cache_folder")) != 0)
+      store_init_sys(arg_get_value(preferences, "plugins_folder"));
 
-    dir = arg_get_value(preferences, "plugins_folder");
-
-    store_init_sys(arg_get_value(preferences, "plugins_folder"));
     plugins = plugins_init(preferences, be_quiet);
 
     if ( first_pass != 0 )
@@ -945,16 +940,11 @@ main(int argc, char * argv[], char * envp[])
     DO_EXIT(0);
   }
 
-  if(getuid())
-  {
-     fprintf(stderr, "Only root should start openvasd.\n");
-     exit(0);
-  }
   if(exit_early == 0)
     bpf_server_pid = bpf_server();
 
 
-  if(iana_port == -1)iana_port = NESIANA_PORT;
+  if(iana_port == -1)iana_port = OPENVAS_IANA_OTP_PORT;
   if (!config_file)
   {
     config_file = emalloc(strlen(OPENVASD_CONF) + 1);
