@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: pluginscheduler.c 1707 2008-11-12 14:30:20Z mwiegand $
+* $Id: pluginscheduler.c 2470 2009-02-13 00:17:32Z jan $
 * Description: Tells openvasd which plugin should be executed next.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -355,7 +355,7 @@ static void hash_fill_deps(struct hash * h, struct hash * l )
 	if ( d != NULL )
 	 l->dependencies_ptr[j++] = d;
         else
-          log_write("%s depends on %s which could not be found\n", l->plugin->arglist->name, l->dependencies[i]);
+          log_write("scheduler: %s depends on %s which could not be found, thus this dependency is not considered for execution sequence\n", l->plugin->arglist->name, l->dependencies[i]);
 	}
    l->dependencies_ptr[j] = NULL;
   }
